#
# spec file for package dssi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dssi
Version:        1.1.1
Release:        13.1
Summary:        Disposable Soft Synth Interface
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND SUSE-Public-Domain
Group:          Development/Libraries/C and C++
URL:            http://dssi.sf.net/
Source:         http://downloads.sourceforge.net/project/dssi/dssi/1.1.1/%{name}-%{version}.tar.gz
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         dssi-add-missing-closedir.diff
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         dssi-linking.patch
# PATCH-FIX-UPSTREAM -- Make the package build with GCC 14
Patch2:         dssi-C99.diff
BuildRequires:  alsa-devel
BuildRequires:  gcc-c++
BuildRequires:  ladspa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Disposable Soft Synth Interface (DSSI, pronounced "dizzy") is a
proposal for a plug-in API for software instruments (soft synths) with
user interfaces, permitting them to be hosted in-process by Linux audio
applications. Think of it as LADSPA-for-instruments or something
comparable to a simpler version of VSTi.

%package devel
Summary:        Development Package for DSSI plugins
Group:          Development/Libraries/C and C++
# note: dssi-devel doesn't require dssi itself; this contains just
# a header and a pkgconfig file.
Requires:       glibc-devel
Requires:       ladspa-devel

%description devel
This package contains files to be needed for building DSSI plugins.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1
%patch -P 2 -p1

%build
mkdir m4
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}%{_libdir}/dssi/*.la
make -C examples clean
rm -rf examples/.deps
rm -f examples/.cvsignore

%files
%defattr(-,root,root)
%doc COPYING README
%doc examples
%dir %{_libdir}/dssi
%{_mandir}/man?/*
%{_bindir}/*
%{_libdir}/dssi

%files devel
%defattr(-,root,root)
%{_includedir}/dssi.h
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Aug 16 2024 Martin Jambor <mjambor@suse.com>
- Added dssi-C99.diff which fixed a callback prototype so that the
  source code adher to C99 and builds with GCC 14.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Oct  5 2014 davejplater@gmail.com
- Own the dssi libdir
* Tue Mar  5 2013 coolo@suse.com
- update license to new format
* Tue Jan 10 2012 reddwarf@opensuse.org
- Update to version 1.1.1:
  * Fix to a crash on startup in one of the example plugins
    (less_trivial_synth)
- Run spec-cleaner
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue Aug 30 2011 crrodriguez@opensuse.org
- Fix linking with new toolchain.
* Wed Sep 22 2010 davejplater@gmail.com
- Update to version 1.1.0
- Upstram changes :
  * Man page updates.
  * Added '-c' option for client name to jack-dssi-host.
  * Fixed configure.ac to check for OS X Qt 4 frameworks, and to add
  '-lX11' to QT_LIBS when Qt is X11-based.
  * Added dssi_list_plugins and dssi_analyse_plugin tools.
  * Updated README for Qt 4 and new tools.
  * Fixed jack-dssi-host.c ALSA client ports to be of type 'application'.
  * Fixed trivial_synth.c getControllerTS() to use DSSI_CC().
  * examples/Makefile.am fixes: reverted trivial_sampler_qt_CXXFLAGS
  to again include $(ALSA_CFLAGS); added math lib to trivial_synth_la_LIBADD.
  * Version bump to 1.0.1.
  * Updated example GUIs to use Qt 4 (thanks to Charles Flèche!)
  * Fixed an uninitialized variable bug in less_trivial_synth.c.
* Fri Jul 24 2009 tiwai@suse.de
- fix dssi-devel not to require dssi itself (no dependecny!)
* Fri Jul 24 2009 tiwai@suse.de
- split to devel sub-package
* Wed Jul 22 2009 tiwai@suse.de
- add missing closedir() (bnc#524217)
* Mon Jan 12 2009 tiwai@suse.de
- updated to version 1.0:
  * man pages
  * updates of jack-dssi-host for new JACK API
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Fri Feb 17 2006 tiwai@suse.de
- clean up binaries in examples (#151896)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 20 2005 tiwai@suse.de
- updated to version 0.9.1.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue Jan 25 2005 meissner@suse.de
- 0 -> NULL in execl, use RPM_OPT_FLAGS
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.9.
  build jack-dssi-host.
* Tue Aug 17 2004 tiwai@suse.de
- initial version: 0.4.
